﻿© 2007 Fluke Corporation, All rights reserved               MET/CAL Procedure
=============================================================================
INSTRUMENT:            Sub Tek TDSxxx Record Reading RS-232
INSTRUMENT:            Sub Tek TDSxxx Cursor Walker RS-232
INSTRUMENT:            Sub Tek TDSxxx Main Trigger RS-232
INSTRUMENT:            Sub Tek TDSxxx Delay Trigger RS-232
INSTRUMENT:            Sub Tek TDSxxx Cursor Reading RS-232
INSTRUMENT:            Sub Tek TDSxxx Check for Trigger RS-232
DATE:                  2007-07-10 10:48:04
AUTHOR:                Fluke Corporation
REVISION:              $Revision: 17918 $
ADJUSTMENT THRESHOLD:  70%
NUMBER OF TESTS:       8
NUMBER OF LINES:       377
=============================================================================
#
# Compatibility:
#   MET/CAL or 5500/CAL 7.0 or later
#
# Subprocedures:
#   Sub Wait for Operation Complete (OPC) RS-232
#
# Required Files:
#   None
#
# REGISTERS USED:
#
#   You will notice that MEM & MEM1 are used extensively in this procedure.
#   This can be dangerous to use since MEM and MEM1 are used for controlling
#   instruments.  We read the values from MEM and MEM1 and store these in
#   temporary registers which are later restored on exiting the sub-procedure.
#
#   M[1]
#     This register is the horizontal start position for the Cursor Walker
#     subprocedure.
#
#   M[2]
#     This register is the horizontal increment for the Cursor Walker
#     subprocedure.
#
#   M[3]
#     This register is the horizontal position for the Cursor Walker
#     subprocedure.
#     This register is the starting trigger level for the Main Trigger
#     and Delay Trigger subprocedures.
#
#   M[4]
#     This register is the trigger level increment for the Main Trigger
#     and Delay Trigger subprocedures.
#
#   M[10]
#     This variable is used to set watchdog timer in the event the
#     oscillscope does not respond to a command.
#
#   M[11]
#     This variable is used to store the value of MEM
#
#   M[12]
#     This variable is used to store the value of MEM1
#
#   M[20]
#     This variable to designate Main (=0) vs Delay (=1) trigger adjust
#
#   S[6]
#     This variable is used to store the trigger "MAIN" or "DELAY".
#
# If the Master Counter is more than 100, we have not been able to
# generate a stable trigger
 STEP    FSC    RANGE NOMINAL        TOLERANCE     MOD1        MOD2  3  4 CON
# Backup MEM and MEM1
  1.001  MATH         M[11] = MEM
  1.002  MATH         M[12] = MEM1

  1.003  JMPL         RECORD_READING               PSUBI("Record Reading")
  1.004  JMPL         CURSOR_WALKER                PSUBI("Cursor Walker")
  1.005  JMPL         MAIN_TRIGGER                 PSUBI("Main Trigger")
  1.006  JMPL         DELAY_TRIGGER                PSUBI("Delay Trigger")
  1.007  JMPL         CURSOR_READING               PSUBI("Cursor Reading")
  1.008  JMPL         CHECK_FOR_TRIGGER            PSUBI("Check for Trigger")
  1.009  DISP         Undefined subprocedure
  1.010  END

  1.011  EVAL   dummy

# ************************* RECORD READING *******************************

# Reset the watchdog counter
  2.001  LABEL        RECORD_READING
  2.002  MATH         M[10] = 0

  2.003  LABEL        CHECK_FOR_STABLE_READING
# We will go through this loop 50 times.  If there is not a good reading
# then we will warn the operator

  2.004  MATH         M[10] = M[10] + 1
  2.005  JMPL         UNSTABLE_READING             M[10] > 50

  2.006  LABEL        READING1
  2.007  PORT         ACQUIRE:STATE RUN[10]
  2.008  CALL         Sub Wait for Operation Complete (OPC) RS-232
  2.009  JMPL         RESTORE_MEM_AND_MEM1         M[89] <= 0
  2.010  PORT         [SREG5][10][I]
  2.011  MATH         M[14] = MEM
  2.012  HEAD         Channel Reading = [MEM]
  2.013  PORT         [D350]

  2.014  LABEL        READING2
  2.015  PORT         ACQUIRE:STATE RUN[10]
  2.016  CALL         Sub Wait for Operation Complete (OPC) RS-232
  2.017  JMPL         RESTORE_MEM_AND_MEM1         M[89] <= 0
  2.018  PORT         [SREG5][10][I]
  2.019  MATH         M[15] = MEM
  2.020  HEAD         Channel Reading = [MEM]
  2.021  PORT         [D350]

  2.022  LABEL        READING3
  2.023  PORT         ACQUIRE:STATE RUN[10]
  2.024  CALL         Sub Wait for Operation Complete (OPC) RS-232
  2.025  JMPL         RESTORE_MEM_AND_MEM1         M[89] <= 0
  2.026  PORT         [SREG5][10][I]
  2.027  HEAD         Channel Reading = [MEM]
  2.028  MATH         M[16] = MEM

  2.029  MATH         M[18] = MIN (14, 16)
  2.030  MATH         M[19] = MAX (14, 16)

# We picked a value of 5 times the resolution of the
# measurement to determine a stable reading.  Other
# factors like noise or condition of the scope will
# have a factor in this.

  2.031  MATH         M[20] = ABS(M[18] - M[19])
  2.032  JMPL         CHECK_FOR_STABLE_READING     M[20] > (5.0 * M[17])
  2.033  JMPL         TAKE_READING

  2.034  LABEL        UNSTABLE_READING
  2.035  OPBR         The Scope has encountered an unstable value.
  2.035  OPBR         Do you wish to take more readings?
  2.036  JMPL         RECORD_READING               MEM1 > 0

# Take one more reading and use it
  2.037  LABEL        TAKE_READING
  2.038  PORT         ACQUIRE:STATE RUN[10]
  2.039  CALL         Sub Wait for Operation Complete (OPC) RS-232
  2.040  JMPL         RESTORE_MEM_AND_MEM1         M[89] <= 0
  2.041  PORT         [SREG5][10][I]
  2.042  HEAD         Channel Reading = [MEM]
# Note, MEM is restored from M[11] at bottom of this procedure.
  2.043  MATH         M[11] = MEM
  2.044  JMPL         RESTORE_MEM_AND_MEM1

  2.045  EVAL   dummy

# ******************** Cursor "Walking" Routine **************************

# This function moves cursor 1 a step at a time until it finds the target
# amplitude of the waveform specified in M[4]. It "returns" a value in
# MEM that is equal to the time at which the amplitude happens.

  3.001  LABEL        CURSOR_WALKER
# Initialize horizontal position (s) and previous vertical amplitude (V).
  3.002  MATH         M[3] = M[1]; M[5] = 0
  3.003  PORT         CURSOR:PAIRED:POSITION1 [M3][10]
  3.004  CALL         Sub Wait for Operation Complete (OPC) RS-232
  3.005  JMPL         RESTORE_MEM_AND_MEM1         M[89] <= 0
  3.006  PORT         [D500]

  3.007  LABEL        WALK_UPRIGHT
# Move the cursor to the horizontal position.
  3.008  PORT         CURSOR:PAIRED:POSITION1 [M3][10]
  3.009  CALL         Sub Wait for Operation Complete (OPC) RS-232
  3.010  JMPL         RESTORE_MEM_AND_MEM1         M[89] <= 0
# Read the vertical amplitude. Throwaway one reading.
  3.011  PORT         [D100]CURSOR:PAIRED:HPOS1?[10][I]
# If vertical amplitude has passed the target value, exit the loop.
  3.012  JMPL         STOP_WALKING                 MEM > M[4]
# Save vertical amplitude for next iteration.
  3.013  MATH         M[5] = MEM
# Increment the horizontal position.
  3.014  MATH         M[3] = M[3] + M[2]
  3.015  JMPL         WALK_UPRIGHT

  3.016  LABEL        STOP_WALKING
# Determine which horizontal position resulted in a vertical amplitude
# closest to the target amplitude.
  3.017  MATH         MEM1 = ABS(MEM - M[4]) < ABS(M[5] - M[4])
  3.018  JMPL         SAVE_HORZ_POS                MEM1
# Use the previous horizontal position.
  3.019  MATH         M[3] = M[3] - M[2]; MEM = M[5]

  3.020  LABEL        SAVE_HORZ_POS
# 3.020  MATH         S[20] = FMT((M[3] / 1E-12), "%.1f")
# 3.021  MATH         S[21] = FMT((MEM / 1E-3), "%.2f")
# 3.022  DISP         Horz. Pos. [S20] ps, Vert. Ampl. [S21] mV, Limit [M4] V
# Note, MEM is restored from M[11] at bottom of this procedure.
  3.021  MATH         M[11] = M[3]
  3.022  JMPL         RESTORE_MEM_AND_MEM1

  3.023  EVAL   dummy

# ****************************** MAIN TRIGGER ********************************

  4.001  LABEL        MAIN_TRIGGER
  4.002  MATH         M[20] = 0

  4.003  LABEL        CHECK_MAIN_TRIGGER
# Trigger Level we will start with
  4.004  PORT         TRIGGER:MAIN SETLEVEL[10]
  4.005  CALL         Sub Wait for Operation Complete (OPC) RS-232
  4.006  JMPL         RESTORE_MEM_AND_MEM1         M[89] <= 0
  4.007  MATH         M[1]  = 0
  4.008  MATH         M[10] = 0
  4.009  PORT         TRIGGER:MAIN:LEVEL [M3][10]

  4.010  LABEL        TEST_MAIN_LEVEL
# Increment Master Watchdog counter
  4.011  MATH         M[1] = M[1] + 1
# If the Master Counter is more than 100, we have not been able to
# generate a stable trigger
  4.012  JMPL         FAIL_MAIN_TRIGGER            M[1] >= 100
# Read the Trigger State
  4.013  PORT         [D250]TRIGGER:STATE?[10][I$]
  4.014  JMPL         PART_OR_TRIG                 M[20] > 0

# If MAIN TRIGGER was called directly the response must TRIGgered.
  4.015  MATH         MEM1 = FIND(MEM2, "TRIG", 1)
  4.016  JMPL         CHECK_MAIN_RESPONSE

  4.017  LABEL        PART_OR_TRIG
# If MAIN TRIGGER was called from DELAY TRIGGER, PARTial or TRIGgered is ok.
  4.018  MATH         MEM1 = FIND(MEM2, "TRIG", 1) + FIND(MEM2, "PART", 1)

  4.019  LABEL        CHECK_MAIN_RESPONSE
  4.020  JMPL         ADJUST_MAIN_LEVEL            MEM1 < 1
# Increment the good trigger counter
  4.021  MATH         M[10] = M[10] + 1
# Jump out of the loop if the system records over 10 good triggers
  4.022  JMPL         END_MAIN_TRIGGER             M[10] > 10
# Go back to the trigger beginning
  4.023  JMPL         TEST_MAIN_LEVEL

  4.024  LABEL        ADJUST_MAIN_LEVEL
# Reset the good trigger counter
  4.025  MATH         M[10] = 0
# If we counted too high, start over
  4.026  JMPL         INCREMENT_MAIN_LEVEL         MEM < ABS(M[3])
  4.027  MATH         MEM = M[3]

  4.028  LABEL        INCREMENT_MAIN_LEVEL
  4.029  MATH         MEM = MEM + M[4]
  4.030  PORT         TRIGGER:MAIN:LEVEL [MEM][10]
  4.031  HEAD         MAIN TRIGGER LEVEL: [MEM]V
  4.032  JMPL         TEST_MAIN_LEVEL

  4.033  LABEL        FAIL_MAIN_TRIGGER
# Set a value for M[10] which will later be evaluated as a failure
  4.034  MATH         M[10] = 0

  4.035  LABEL        END_MAIN_TRIGGER
  4.036  JMPL         CHECK_DELAY_TRIGGER          M[20] > 0
  4.037  JMPL         RESTORE_MEM_AND_MEM1

  4.038  EVAL   dummy

# ************************* DELAY TRIGGER ********************************

  5.001  LABEL        DELAY_TRIGGER
  5.002  MATH         M[20] = 1

  5.003  LABEL        CHECK_DELAY_TRIGGER
# Set a flag
  5.004  MATH         M[1]  = 0
  5.005  MATH         M[10] = 0
  5.006  PORT         TRIGGER:DELAY:LEVEL [M3][10]

  5.007  LABEL        TEST_DELAY_LEVEL
# Increment Master Watchdog counter
  5.008  MATH         M[1] = M[1] + 1
  5.009  JMPL         FAIL_DELAY_TRIGGER           M[1] >= 100
# Read the Trigger State
  5.010  PORT         [D250]TRIGGER:STATE?[10][I$]
# If "REAdy", we need to re-adjust the main trigger level.
  5.011  JMPL         CHECK_MAIN_TRIGGER           FIND(MEM2, "REA", 1)
  5.012  MATH         MEM1 = FIND(MEM2, "TRIG", 1)
# If "PARTial", we need to adjust the delay trigger Level.
  5.013  JMPL         ADJUST_DELAY_LEVEL           FIND(MEM2, "PART", 1)
# Increment the good trigger counter
  5.014  MATH         M[10] = M[10] + 1
# Jump out of the loop if the system records over 10 good triggers
  5.015  JMPL         END_DELAY_TRIGGER            M[10] > 10
# Go back to the trigger beginning
  5.016  JMPL         TEST_DELAY_LEVEL

  5.017  LABEL        ADJUST_DELAY_LEVEL
# Reset the good trigger counter
  5.018  MATH         M[10] = 0.0
# If we counted too high, start over
  5.019  JMPL         DELAY_ADD_LEVEL              MEM < ABS(M[3])
  5.020  MATH         MEM = M[3]

  5.021  LABEL        DELAY_ADD_LEVEL
  5.022  MATH         MEM = MEM + M[4]
  5.023  PORT         TRIGGER:DELAY:LEVEL [MEM][10]
  5.024  HEAD         DELAY TRIGGER LEVEL: [MEM]V
  5.025  JMPL         TEST_DELAY_LEVEL

  5.026  LABEL        FAIL_DELAY_TRIGGER
# Set a value for M[10] which will later be evaluated as a failure
  5.027  MATH         M[10] = 0

  5.028  LABEL        END_DELAY_TRIGGER
  5.029  JMPL         RESTORE_MEM_AND_MEM1

  5.030  EVAL   dummy

# ************************* CURSOR_READING *******************************

  6.001  LABEL        CURSOR_READING
  6.002  PORT         ACQUIRE:STATE RUN[10]
  6.003  CALL         Sub Wait for Operation Complete (OPC) RS-232
  6.004  JMPL         RESTORE_MEM_AND_MEM1         M[89] <= 0
  6.005  PORT         [SREG5][10][I]
  6.006  MATH         M[14] = MEM
  6.007  HEAD         Channel Reading = [MEM]
  6.008  PORT         [D350]

  6.009  LABEL        READING2
  6.010  PORT         ACQUIRE:STATE RUN[10]
  6.011  CALL         Sub Wait for Operation Complete (OPC) RS-232
  6.012  JMPL         RESTORE_MEM_AND_MEM1         M[89] <= 0
  6.013  PORT         [SREG5][10][I]
  6.014  MATH         M[15] = MEM
  6.015  HEAD         Channel Reading = [MEM]
  6.016  PORT         [D350]

  6.017  LABEL        READING3
  6.018  PORT         ACQUIRE:STATE RUN[10]
  6.019  CALL         Sub Wait for Operation Complete (OPC) RS-232
  6.020  JMPL         RESTORE_MEM_AND_MEM1         M[89] <= 0
  6.021  PORT         [SREG5][10][I]
  6.022  HEAD         Channel Reading = [MEM]
  6.023  MATH         M[16] = MEM

  6.024  MATH         M[18] = MIN (14, 16)
  6.025  MATH         M[19] = MAX (14, 16)

  6.026  MATH         M[11] = M[19]
  6.027  JMPL         RESTORE_MEM_AND_MEM1

  6.028  EVAL   dummy

# *************************** CHECK FOR TRIGGER *****************************

# Wait up to 5s for UUT to trigger.

  7.001  LABEL        CHECK_FOR_TRIGGER
  7.002  MATH         M[10] = 0

  7.003  LABEL        CHECK_FOR_TRIGGER_LOOP
  7.004  PORT         TRIGGER:STATE?[10][I$]
  7.005  MATH         M[12] = FIND(MEM2, "TRIG", 1)
  7.006  JMPL         RESTORE_MEM_AND_MEM1         M[12] > 0
  7.007  MATH         M[10] = M[10] + 1
  7.008  JMPL         RESTORE_MEM_AND_MEM1         M[10] > 5
  7.009  PORT         [D1000]
  7.010  JMPL         CHECK_FOR_TRIGGER_LOOP

  7.011  JMPL         RESTORE_MEM_AND_MEM1

  7.012  EVAL   dummy

# ************************* END OF PROCEDURES ****************************

  8.001  LABEL        RESTORE_MEM_AND_MEM1
  8.002  MATH         MEM = M[11]
  8.003  MATH         MEM1 = M[12]
  8.004  END
